@@ -20,7 +20,7 @@ class record:
         self.date=datetime.date(y,m,dd)
 
 title = "Munipack"
-link = "http://munipack.physics.muni.cz/"
+link = "https://munipack.physics.muni.cz/"
 description = "A general astronomical image processing software"
 
 feed = fd.Atom1Feed(title,link,description,author_name="Filip Hroch",
@@ -39,7 +39,9 @@ records = [
    record("0.5.9",link,"Artificial Sky",2017,07,18),
    record("0.5.10",link,"Flat-fielding",2018,01,16),
    record("0.5.11",link,"Oak Leaf",2019,01,22),
-   record("0.5.12",link,"Bullseye",2020,11,30)
+   record("0.5.12",link,"Bullseye",2020,11,30),
+   record("0.5.13",link,"Bullseye",2020,12,21),
+   record("0.5.14",link,"Bullseye",2021,02,04)
 ]
 
 for r in records:
