@@ -40,7 +40,7 @@ def ucac_jmuc(ucac,jmuc):
 
     # write to the new table
     f = fitsio.BinTableHDU.from_columns(d)
-    f.writeto(jmuc,clobber=True)
+    f.writeto(jmuc,overwrite=True)
 
 
 
