@@ -2,7 +2,7 @@
 
   Cone search
 
-  Copyright © 2010 - 2015, 2017-18 F.Hroch (hroch@physics.muni.cz)
+  Copyright © 2010 - 2015, 2017-19 F.Hroch (hroch@physics.muni.cz)
 
   This file is part of Munipack.
 
@@ -128,10 +128,10 @@ bool Munipack::cone(MuniProcess *c, MuniCmdLineParser& cmd)
     c->Write("SORT = '"+sort+"'");
 
   if( cmd.Found("magmin",&mag) )
-    c->Write("MAGMIN = '"+ wxString::FromCDouble(mag) +"'");
+    c->Write("MAGMIN = "+wxString::FromCDouble(mag));
 
   if( cmd.Found("magmax",&mag) )
-    c->Write("MAGMAX = '"+ wxString::FromCDouble(mag) +"'");
+    c->Write("MAGMAX = "+wxString::FromCDouble(mag));
 
   if( cmd.Found("Johnson-patch") )
     c->Write("PATCH = T");
