@@ -2,7 +2,7 @@
 
   Average of darks
 
-  Copyright © 2010-2013 F.Hroch (hroch@physics.muni.cz)
+  Copyright © 2010-2013, 2018 F.Hroch (hroch@physics.muni.cz)
 
   This file is part of Munipack.
 
@@ -10,12 +10,12 @@
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation, either version 3 of the License, or
   (at your option) any later version.
-  
+
   Munipack is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
-  
+
   You should have received a copy of the GNU General Public License
   along with Munipack.  If not, see <http://www.gnu.org/licenses/>.
 
@@ -28,14 +28,13 @@ bool Munipack::dark(MuniProcess *action, MuniCmdLineParser& cmd)
 {
   CommonOutputSingle(action,cmd);
   CommonOptionsBitpix(action,cmd);
-  CommonOptionsArith(action,cmd);
+  CommonOptionsPhCorr(action,cmd);
+  EnvironmentPhCorr(action);
 
   wxString a;
   if( cmd.Found("bias",&a) )
     action->Write("BIAS = '"+a+"'");
 
-  for(size_t i = 0; i < cmd.GetParamCount(); i++)
-    WriteFile(action,cmd.GetParam(i));
-
+  WriteFiles(action,cmd.GetFiles());
   return true;
 }
