@@ -2,7 +2,7 @@
 
   Growth-Curve Photometry
 
-  Copyright © 2016 F.Hroch (hroch@physics.muni.cz)
+  Copyright © 2016-8 F.Hroch (hroch@physics.muni.cz)
 
   This file is part of Munipack.
 
@@ -39,8 +39,7 @@ bool Munipack::gphot(MuniProcess *action, MuniCmdLineParser& cmd)
   if( cmd.Found("th",&x) || cmd.Found("threshold",&x) )
     action->Write("THRESHOLD = %lf",x);
 
-  for(size_t i = 0; i < cmd.GetParamCount(); i++)
-    WriteFiles(action,cmd.GetParam(i));
+  WriteFiles(action,cmd);
 
   return true;
 }
