@@ -2,7 +2,7 @@
 
   Growth-Curve Photometry Report
 
-  Copyright © 2016 F.Hroch (hroch@physics.muni.cz)
+  Copyright © 2016, 2018 F.Hroch (hroch@physics.muni.cz)
 
   This file is part of Munipack.
 
@@ -27,8 +27,8 @@
 
 bool Munipack::grow_report(MuniProcess *action, MuniCmdLineParser& cmd)
 {
-  for(size_t i = 0; i < cmd.GetParamCount(); i++)
-    action->Write("FILE = '"+cmd.GetParam(i)+"'");
+  for(size_t i = 0; i < cmd.GetFilesCount(); i++)
+    action->Write("FILE = '"+cmd.GetFile(i)+"'");
 
   return true;
 }
