@@ -2,7 +2,7 @@
 
   Photometric corrections
 
-  Copyright © 2012-3, 2016, 2018 F.Hroch (hroch@physics.muni.cz)
+  Copyright © 2012-3, 2016, 2018-9 F.Hroch (hroch@physics.muni.cz)
 
   This file is part of Munipack.
 
@@ -28,7 +28,7 @@ bool Munipack::phcorr(MuniProcess *action, MuniCmdLineParser& cmd)
 {
   CommonOptionsBitpix(action,cmd);
   CommonOutputMultiple(action,cmd);
-  CommonOptionsClobber(action,cmd);
+  CommonOptionsEnableOverwrite(action,cmd);
   EnvironmentPhCorr(action);
 
   wxString a;
