@@ -3,7 +3,7 @@
   xmunipack - file browser window
 
 
-  Copyright © 2009-2012 F.Hroch (hroch@physics.muni.cz)
+  Copyright © 2009-2012, 2019-20 F.Hroch (hroch@physics.muni.cz)
 
   This file is part of Munipack.
 
@@ -24,6 +24,7 @@
 
 
 #include "xmunipack.h"
+#include "help.h"
 #include <algorithm>
 #include <vector>
 #include <typeinfo>
@@ -49,8 +50,6 @@ MuniBrowser::MuniBrowser(wxWindow *w, MuniConfig *c):
 	  c->browser_size, wxDEFAULT_FRAME_STYLE),
   config(c),
   archive(new MuniArchive(GetEventHandler(),config->confdir)),
-//  console(new MuniConsole(this,config)),
-  console(new wxLogWindow(this,"Logs",false)),
   menuView(new wxMenu), menuAct(new wxMenu),
   menuArrange(new wxMenu), menuLabels(new wxMenu), list(0),
   view(0),
@@ -221,10 +220,8 @@ MuniBrowser::MuniBrowser(wxWindow *w, MuniConfig *c):
   menuGo->Append(wxID_HOME);
 
   menuHelp = new wxMenu;
-  menuHelp->Append(wxID_HELP,wxEmptyString,"A web connection to " HOMEPAGE);
   //  menuHelp->AppendCheckItem(ID_LOG,"&Log...");
-  menuHelp->Append(ID_LOG,"Log");
-  //  menuHelp->Append(ID_BUG,"Report a Bug ...","Launch your default browser to Munipack's issues.");
+  //  menuHelp->Append(ID_LOG,"Log");
   menuHelp->Append(wxID_ABOUT);
 
   wxMenuBar *menuBar = new wxMenuBar;
@@ -324,9 +321,9 @@ MuniBrowser::MuniBrowser(wxWindow *w, MuniConfig *c):
   Bind(wxEVT_COMMAND_MENU_SELECTED,&MuniBrowser::OnZoom,this,wxID_ZOOM_OUT);
   Bind(wxEVT_COMMAND_MENU_SELECTED,&MuniBrowser::OnShowToolbar,this,ID_TOOLBAR);
   Bind(wxEVT_COMMAND_MENU_SELECTED,&MuniBrowser::OnShowCollector,this,ID_COLLECTOR);
-  Bind(wxEVT_COMMAND_MENU_SELECTED,&MuniBrowser::ViewLog,this,ID_LOG);
-  Bind(wxEVT_COMMAND_MENU_SELECTED,&MuniBrowser::ShowLog,this,ID_WARNING);
-  Bind(wxEVT_COMMAND_MENU_SELECTED,&MuniBrowser::FindStars,this,ID_FIND);
+  //  Bind(wxEVT_COMMAND_MENU_SELECTED,&MuniBrowser::ViewLog,this,ID_LOG);
+  //  Bind(wxEVT_COMMAND_MENU_SELECTED,&MuniBrowser::ShowLog,this,ID_WARNING);
+  //  Bind(wxEVT_COMMAND_MENU_SELECTED,&MuniBrowser::FindStars,this,ID_FIND);
   //  Bind(wxEVT_COMMAND_MENU_SELECTED,&MuniBrowser::AperturePhot,this,ID_PHOT);
   Bind(wxEVT_COMMAND_MENU_SELECTED,&MuniBrowser::ProfilePhot,this,ID_PROFILE);
   Bind(wxEVT_COMMAND_MENU_SELECTED,&MuniBrowser::Matching,this,ID_MATCH);
@@ -336,9 +333,7 @@ MuniBrowser::MuniBrowser(wxWindow *w, MuniConfig *c):
   Bind(wxEVT_COMMAND_MENU_SELECTED,&MuniBrowser::OnAverage,this,ID_AVERAGE);
   Bind(wxEVT_COMMAND_MENU_SELECTED,&MuniBrowser::OnDarkbat,this,ID_DARKBAT);
   Bind(wxEVT_COMMAND_MENU_SELECTED,&MuniBrowser::OnList,this,ID_LIST);
-  Bind(wxEVT_COMMAND_MENU_SELECTED,&MuniBrowser::HelpHelp,this,wxID_HELP);
   Bind(wxEVT_COMMAND_MENU_SELECTED,&MuniBrowser::HelpAbout,this,wxID_ABOUT);
-  //  Bind(wxEVT_COMMAND_MENU_SELECTED,&MuniBrowser::HelpBug,this,ID_BUG);
   Bind(wxEVT_COMMAND_SEARCHCTRL_CANCEL_BTN,&MuniBrowser::OnSearch,this,wxID_FIND);
   Bind(wxEVT_COMMAND_SEARCHCTRL_CANCEL_BTN,&MuniBrowser::OnSearchFinish,this,wxID_FIND);
   Bind(wxEVT_COMMAND_TREE_SEL_CHANGED,&MuniBrowser::OnSelChanged,this);
@@ -745,20 +740,6 @@ void MuniBrowser::OnView(wxCommandEvent& WXUNUSED(event))
 // }
 
 
-void MuniBrowser::ShowLog(wxCommandEvent& event)
-{
-  tbot->RemoveTool(ID_WARNING);
-  tbot->Realize();
-  wxASSERT(console);
-  console->Show(true);
-}
-
-void MuniBrowser::ViewLog(wxCommandEvent& event)
-{
-  wxASSERT(console);
-  console->Show();
-}
-
 void MuniBrowser::FindStars(wxCommandEvent& WXUNUSED(event))
 {
   //  SetStatusText(wxT("FindStars is not implemenetd yet."));
@@ -829,25 +810,11 @@ void MuniBrowser::OnAverage(wxCommandEvent& WXUNUSED(event))
   SwitchList(ID_AVERAGE);
 }
 
-void MuniBrowser::HelpHelp(wxCommandEvent& WXUNUSED(event))
-{
-  MuniHelp *h = new MuniHelp(config);
-  h->Show(true);
-  //  wxLaunchDefaultBrowser();
-}
-
 void MuniBrowser::HelpAbout(wxCommandEvent& WXUNUSED(event))
 {
   MuniAbout(config->munipack_icon);
 }
 
-/*
-void MuniBrowser::HelpBug(wxCommandEvent& WXUNUSED(event))
-{
-  wxLaunchDefaultBrowser(BUGPAGE);
-}
-*/
-
 void MuniBrowser::OnLabel(wxCommandEvent& event)
 {
   list->Label(event.GetId());
