@@ -45,11 +45,20 @@
 #define MUNIVIEW_WIDTH       "MuniView_width"
 #define MUNIVIEW_HEIGHT      "MuniView_height"
 #define MUNIVIEW_TBAR        "MuniView_tbar"
+#define MUNIDETAIL_SHOW      "MuniDetail_show"
 #define MUNIDETAIL_SCALE     "MuniDetail_scale"
 #define MUNIDETAIL_ZOOM      "MuniDetail_zoom"
+#define MUNIMAGNIFIER_SCALE  "MuniMagnifier_scale"
+#define MUNIMAGNIFIER_SHOW   "MuniMagnifier_show"
+#define MUNIMAGNIFIER_WIDTH  "MuniMagnifier_width"
+#define MUNIMAGNIFIER_HEIGHT "MuniMagnifier_height"
+#define MUNIEXTLIST_SHOW     "MuniExtlist_show"
+#define MUNICAPTION_SHOW     "MuniCaption_show"
+/*
 #define MUNICONSOLE_WIDTH    "MuniConsole_width"
 #define MUNICONSOLE_HEIGHT   "MuniConsole_height"
 #define MUNICONSOLE_WRAP     "MuniConsole_wrap"
+*/
 #define MUNIHELP_WIDTH       "MuniHelp_width"
 #define MUNIHELP_HEIGHT      "MuniHelp_height"
 #define MUNIHEADER_WIDTH     "MuniHeader_width"
@@ -61,18 +70,23 @@
 #define ASTROMETRY_PROJ      "Astrometry_proj"
 #define ASTROMETRY_SIG       "Astrometry_sig"
 #define ASTROMETRY_FSIG      "Astrometry_fsig"
-#define PHOTOMETRY_FWHM      "Astrometry_fwhm"
-#define PHOTOMETRY_THRESH    "Astrometry_thresh"
-#define PHOTOMETRY_SATUR     "Astrometry_satur"
-#define PHOTOMETRY_READNS    "Astrometry_readns"
-#define PHOTOMETRY_PHPADU    "Astrometry_phpadu"
+#define FIND_FWHM            "Find_fwhm"
+#define FIND_THRESH          "Find_thresh"
+#define APHOT_NAPER          "Aphot_naper"
+#define APHOT_RMIN           "Aphot_rmin"
+#define APHOT_RMAX           "Aphot_rmax"
+#define APHOT_ZOOM           "Aphot_zoom"
+#define APHOT_SAPER          "Aphot_saper"
+#define APHOT_SPIRAL         "Aphot_spiral"
+#define APHOT_SNAP           "Aphot_snap"
+#define APHOT_WIDTH          "Aphot_width"
+#define APHOT_HEIGHT         "Aphot_height"
 #define ICON_SIZE            "Icon_size"
 #define ICON_SMALL           "Icon_small"
 #define ICON_ZOOM            "Icon_zoom"
 #define SCROLL_RATE          "Scroll_rate"
 #define DISPLAY_PAL          "Display_pal"
 #define DISPLAY_PALINV       "Display_palinv"
-#define DISPLAY_PALAUTO      "Display_palauto"
 #define DISPLAY_COO          "Display_coo"
 #define DISPLAY_VAL          "Display_val"
 #define DISPLAY_GRID         "Display_grid"
@@ -141,14 +155,25 @@ MuniConfig::MuniConfig():
   Read(MUNIVIEW_TBAR,&view_tbar,1);
   view_size = wxSize(w,h);
 
+  Read(MUNICAPTION_SHOW,&caption_show,1);
+  Read(MUNIDETAIL_SHOW,&detail_show,0);
   Read(MUNIDETAIL_SCALE,&detail_scale,4);
   Read(MUNIDETAIL_ZOOM,&detail_zoom,40);
 
+  Read(MUNIMAGNIFIER_SCALE,&magnifier_scale,4);
+  Read(MUNIMAGNIFIER_SHOW,&magnifier_show,0);
+  Read(MUNIMAGNIFIER_WIDTH,&w,42);
+  Read(MUNIMAGNIFIER_HEIGHT,&h,42);
+  magnifier_size = wxSize(w,h);
+
+  Read(MUNIEXTLIST_SHOW,&extlist_show,1);
+
+  /*
   Read(MUNICONSOLE_WIDTH,&w,width/2);
   Read(MUNICONSOLE_HEIGHT,&h,height/2);
   console_size = wxSize(w,h);
-
   Read(MUNICONSOLE_WRAP,&console_wrap,0);
+  */
 
   Read(MUNIHELP_WIDTH,&w,3*width/5);
   Read(MUNIHELP_HEIGHT,&h,4*height/5);
@@ -166,11 +191,19 @@ MuniConfig::MuniConfig():
   Read(ASTROMETRY_FSIG,&astrometry_fsig,5.0);
   Read(ASTROMETRY_UNITS,&astrometry_units,"arcsec");
 
-  Read(PHOTOMETRY_FWHM,&photo_fwhm,2.0);
-  Read(PHOTOMETRY_THRESH,&photo_thresh,5.0);
-  Read(PHOTOMETRY_SATUR,&photo_satur,DBL_MAX);
-  Read(PHOTOMETRY_READNS,&photo_readns,0.0);
-  Read(PHOTOMETRY_PHPADU,&photo_phpadu,1.0);
+  Read(FIND_FWHM,&find_fwhm,3.0);
+  Read(FIND_THRESH,&find_thresh,7.0);
+
+  Read(APHOT_NAPER,&aphot_naper,12);
+  Read(APHOT_RMIN,&aphot_rmin,20);
+  Read(APHOT_RMAX,&aphot_rmax,30);
+  Read(APHOT_ZOOM,&aphot_zoom,4);
+  Read(APHOT_SAPER,&aphot_saper,0);
+  Read(APHOT_SPIRAL,&aphot_spiral,1);
+  Read(APHOT_SNAP,&aphot_snap,1);
+  Read(APHOT_WIDTH,&w,-1);
+  Read(APHOT_HEIGHT,&h,-1);
+  aphot_size = wxSize(w,h);
 
   Read(ICON_SIZE,&icon_size,150);
   Read(ICON_SMALL,&icon_small,30);
@@ -236,7 +269,6 @@ MuniConfig::MuniConfig():
   }
 
   Read(DISPLAY_PALINV,&display_palinv, 0);
-  Read(DISPLAY_PALAUTO,&display_palauto, 0);
   Read(DISPLAY_GRID, &display_grid, 0);
   Read(DISPLAY_SOURCES, &display_sources, 0);
 
@@ -295,11 +327,20 @@ MuniConfig::~MuniConfig()
   Write(MUNIVIEW_WIDTH,view_size.GetWidth());
   Write(MUNIVIEW_HEIGHT,view_size.GetHeight());
   Write(MUNIVIEW_TBAR,view_tbar);
+  Write(MUNICAPTION_SHOW,caption_show);
+  Write(MUNIDETAIL_SHOW,detail_show);
   Write(MUNIDETAIL_SCALE,detail_scale);
   Write(MUNIDETAIL_ZOOM,detail_zoom);
+  Write(MUNIMAGNIFIER_SCALE,magnifier_scale);
+  Write(MUNIMAGNIFIER_SHOW,magnifier_show);
+  Write(MUNIMAGNIFIER_WIDTH,magnifier_size.GetWidth());
+  Write(MUNIMAGNIFIER_HEIGHT,magnifier_size.GetHeight());
+  Write(MUNIEXTLIST_SHOW,extlist_show);
+  /*
   Write(MUNICONSOLE_WIDTH,console_size.GetWidth());
   Write(MUNICONSOLE_HEIGHT,console_size.GetHeight());
   Write(MUNICONSOLE_WRAP,console_wrap);
+  */
   Write(MUNIHELP_WIDTH,help_size.GetWidth());
   Write(MUNIHELP_HEIGHT,help_size.GetHeight());
   Write(MUNIHEADER_WIDTH,header_size.GetWidth());
@@ -349,14 +390,21 @@ MuniConfig::~MuniConfig()
   Write(ASTROMETRY_SIG,astrometry_sig);
   Write(ASTROMETRY_FSIG,astrometry_fsig);
   Write(ASTROMETRY_UNITS,astrometry_units);
-  Write(PHOTOMETRY_FWHM,photo_fwhm);
-  Write(PHOTOMETRY_THRESH,photo_thresh);
-  Write(PHOTOMETRY_SATUR,photo_satur);
-  Write(PHOTOMETRY_READNS,photo_readns);
-  Write(PHOTOMETRY_PHPADU,photo_phpadu);
+  Write(FIND_FWHM,find_fwhm);
+  Write(FIND_THRESH,find_thresh);
+
+  Write(APHOT_NAPER,aphot_naper);
+  Write(APHOT_RMIN,aphot_rmin);
+  Write(APHOT_RMAX,aphot_rmax);
+  Write(APHOT_ZOOM,aphot_zoom);
+  Write(APHOT_SAPER,aphot_saper);
+  Write(APHOT_SPIRAL,aphot_spiral);
+  Write(APHOT_SNAP,aphot_snap);
+  Write(APHOT_WIDTH,aphot_size.GetWidth());
+  Write(APHOT_HEIGHT,aphot_size.GetHeight());
+
   Write(DISPLAY_PAL,FitsPalette::Type_str(display_pal));
   Write(DISPLAY_PALINV,display_palinv);
-  Write(DISPLAY_PALAUTO,display_palauto);
   Write(DISPLAY_GRID,display_grid);
   Write(DISPLAY_SOURCES,display_sources);
   Write(DISPLAY_COO,FitsCoo::Label_str(display_coo));
@@ -428,55 +476,3 @@ wxImage MuniConfig::LoadImage(const wxString& name)
     return b.ConvertToImage();
   }
 }
-
-
-MuniArtIcons::MuniArtIcons(const wxArtClient& c, const wxSize& s):
-  client(c), size(s)
-{}
-
-wxBitmap MuniArtIcons::Icon(const wxArtID& id) const
-{
-#ifdef __WXMAC__
-  wxString name;
-  if( id == "zoom-fit-best" )
-    name = "stock_zoom_fit_width");
-  else if( id == "zoom-original" )
-    name = "stock_zoom_one_to_one";
-  else if( id == "preferences-desktop" )
-    name = "stock_preferences";
-  else if( id == "wxART_GO_UP" )
-    name = "stock_up";
-  else if( id == "wxART_GO_HOME" )
-    name = "stock_home";
-  else if( id == "wxART_GO_BACK" )
-    name = "stock_back";
-  else if( id == "wxART_GO_FORWARD" )
-    name = "stock_forward";
-  else if( id == "wxART_FOLDER" )
-    name = "stock_folder";
-  else if( id == "stop" )
-    name = "stock_cancel";
-  else if( id == "view-refresh" )
-    name = "stock_refresh";
-
-  wxString a(id);
-  //  wxLogDebug(wxT("MuniArtIcons::Icon ") +a);
-  wxString fullpath = MuniConfig::FindIconPath(name+".png");
-  if( ! fullpath.IsEmpty() ) {
-
-    //    wxLogDebug(wxT("MuniArtIcons::Icon %s"),fullpath.c_str());
-    wxImage icona(fullpath);
-    if( icona.Ok() ) {
-      return wxBitmap(icona);
-    }
-  }
-  return wxArtProvider::GetBitmap(wxART_MISSING_IMAGE,client,size);
-
-#else
-
-  wxBitmap b = wxArtProvider::GetBitmap(id,client,size);
-  if( ! b.IsOk() )
-    b = wxArtProvider::GetBitmap(wxART_MISSING_IMAGE,client,size);
-  return b;
-#endif
-}
