@@ -188,7 +188,7 @@ MuniCanvasMini::MuniCanvasMini(wxWindow *w, int z, int s):
 
   Bind(wxEVT_PAINT,&MuniCanvasMini::OnPaint,this);
   Bind(wxEVT_UPDATE_UI,&MuniCanvasMini::OnUpdate,this);
-  Bind(xEVT_SLEW,&MuniCanvasMini::OnMouseMotion,this);
+  Bind(EVT_SLEW,&MuniCanvasMini::OnMouseMotion,this);
   Bind(EVT_FULLTUNE,&MuniCanvasMini::OnFullTune,this);
 }
 
@@ -240,8 +240,10 @@ void MuniCanvasMini::OnPaint(wxPaintEvent& event)
 void MuniCanvasMini::OnUpdate(wxUpdateUIEvent& event)
 {
   event.SetUpdateInterval(40); // = 1/25 s
-  Render(crosshair);
-  Refresh();
+  if( tone.IsOk() ) {
+    Render(crosshair);
+    Refresh();
+  }
 }
 
 
