@@ -48,7 +48,7 @@ MuniDisplayCanvas::MuniDisplayCanvas(wxWindow *w, MuniConfig *c):
 {
   wxLogDebug("MuniDisplayCanvas constructor..");
 
-  SetBackgroundStyle(wxBG_STYLE_PAINT);
+  SetBackgroundColour(wxColour("black"));
 
   pal.SetPalette(config->display_pal);
   pal.SetInverse(config->display_palinv);
