@@ -21,34 +21,16 @@
 
 */
 
-#ifndef _MUNI_PLOT_H_
 #include "plot.h"
-#endif
-
-#ifndef _FITS_H_
 #include "fits.h"
-#endif
-
-#ifndef _XMUNIPACK_ENUM_H_
 #include "enum.h"
-#endif
-
-#ifndef _XMUNIPACK_EVENT_H_
 #include "event.h"
-#endif
-
-#ifndef _XMUNIPACK_CONFIG_H_
 #include "mconfig.h"
-#endif
-
-#ifndef _XMUNIPACK_TYPES_H_
 #include "types.h"
-#endif
-
 #include <wx/wx.h>
 #include <wx/html/htmlwin.h>
 #include <list>
-
+#include <map>
 
 class MuniCanvasMini: public wxWindow
 {
@@ -195,23 +177,23 @@ public:
   MuniDisplayCanvas(wxWindow *w, MuniConfig *c);
   virtual ~MuniDisplayCanvas();
 
-  void SetHandler(wxEvtHandler *);
-  void SetHdu(const FitsArray&, const wxImage&, bool);
+  void SetHdu(const FitsArray&, const wxImage&);
+  void SetInitShrink(int);
+  void InvokeRendering();
   void StopRendering();
-  FitsZoom GetZoom() const;
   FitsTone GetTone() const { return tone; };
   FitsItt GetItt() const { return itt; };
   FitsPalette GetPalette() const { return pal; }
   FitsColor GetColor() const { return color; }
-  wxImage GetImage() { return canvas; }
-  int GetFitShrink() const;
+  wxImage GetImage() const;
+  wxPoint GetCartesianPosition(const wxPoint&) const;
 
   void OnTuneFine(MuniTuneEvent&);
-  void OnMenuPalauto(wxCommandEvent&);
   void OnValueType(wxCommandEvent&);
   void OnCooType(wxCommandEvent&);
   void OnAstrometry(MuniAstrometryEvent&);
   void OnPhotometry(MuniPhotometryEvent&);
+  void OnDraw(MuniDrawEvent&);
   void AddLayer(const MuniLayer&);
   void RemoveLayers(int);
 
@@ -239,8 +221,8 @@ private:
   int value_type, coo_type;
   int scaleicon;
   int shrink, zoom;
-  bool palauto, zooming, update_zoom, shrinking, tunning, completed;
-  bool dragging,rendering;
+  bool zooming, update_zoom, shrinking, tunning, completed;
+  bool dragging,invoking,rendering,finished;
   bool astrometry;
   double xcen, ycen, acen, dcen, ascale, aangle;
   wxPoint crosshair;
@@ -250,7 +232,10 @@ private:
   void OnSize(wxSizeEvent&);
   void OnPaint(wxPaintEvent&);
   void OnMouseMotion(wxMouseEvent&);
+  void OnMouseEnter(wxMouseEvent&);
+  void OnMouseLeave(wxMouseEvent&);
   void OnMouseWheel(wxMouseEvent&);
+  void OnClick(wxMouseEvent&);
   void OnLeftUp(wxMouseEvent&);
   void OnRenderFinish(MuniRenderEvent&);
   void OnSubRender(MuniRenderEvent&);
@@ -265,16 +250,142 @@ private:
   //  void DrawSVG(wxPaintDC&, const wxXmlDocument&);
   void DrawLayer(wxPaintDC&, const MuniLayer&);
   void ConvertCoo(double,double,double&,double&);
-  wxPoint GetCartesianPosition(const wxPoint&) const;
 
   void InitCanvas();
   void UpdateCanvas(int,int);
   void UpdateCanvas();
   void UpdateTune();
-  void UpdateScale(bool, int);
+  void UpdateScale(int);
   void UpdateScale();
   void UpdateScroll();
   void StartRendering();
-  void SelectAutoPal();
+
+};
+
+class MuniDisplayCaptionInfo: public wxPanel
+{
+  MuniConfig *config;
+  FitsArray array;
+  bool init;
+
+  wxStaticText *object, *colour, *exptime, *date, *time,
+    *label_object, *label_colour;
+
+  void OnIdle(wxIdleEvent&);
+
+public:
+  MuniDisplayCaptionInfo(wxWindow *, MuniConfig *);
+  void SetArray(const FitsArray&);
+
+};
+
+
+class MuniDisplayCaptionColour: public wxPanel
+{
+  FitsArray array;
+  bool cie1931xyz;
+  wxStaticText *colours[3];
+  bool update;
+  double x,y;
+
+  void OnIdle(wxIdleEvent&);
+  void OnMouseMotion(MuniSlewEvent&);
+  wxString print(float);
+
+public:
+  MuniDisplayCaptionColour(wxWindow *, bool);
+  void SetArray(const FitsArray&);
+  void UnsetArray();
+
+};
+
+class MuniDisplayCaptionMotion: public wxPanel
+{
+  MuniConfig *config;
+  FitsValue value;
+  FitsCoo coords;
+  FitsArray array;
+  wxString cspace;
+
+  wxStaticText *quantity, *label_quantity, *units_quantity,
+    *alpha, *delta, *xpix, *ypix;
+  wxFlexGridSizer *quantitysizer, *pixsizer, *coosizer;
+  wxButton *options;
+  MuniDisplayCaptionColour *xyz, *lab;
+  std::map<long,wxString> hash;
+  bool init, update, hascal, show_wcs;
+  int x,y;
+
+  void OnIdle(wxIdleEvent&);
+  void OnOptions(wxCommandEvent&);
+  void OnPopOptions(wxCommandEvent&);
+  void OnMouseMotion(MuniSlewEvent&);
+
+public:
+  MuniDisplayCaptionMotion(wxWindow *, MuniConfig *);
+  void SetArray(const FitsArray&);
+
+};
+
+class MuniDisplayCaption: public wxPanel
+{
+  MuniConfig *config;
+  wxTimer timer;
+  wxRect rect;
+  bool inside;
+
+  MuniDisplayCaptionInfo *info;
+  MuniDisplayCaptionMotion *motion;
+
+  void OnMouseMotion(MuniSlewEvent&);
+  void OnTimer(wxTimerEvent&);
+
+public:
+  MuniDisplayCaption(wxWindow *, MuniConfig *);
+  void SetArray(const FitsArray&);
+
+};
+
+class MuniMagnifierGlass: public wxWindow
+{
+  int width, height, scale;
+  bool defined;
+  wxBitmap canvas;
+  wxImage image;
+  wxPoint crosshair;
+
+  void OnPaint(wxPaintEvent&);
+  void OnSize(wxSizeEvent&);
+  void UpdateCanvas(int,int,int,int);
+  void UpdateBlur(wxDC&);
+  void RandomBlur(wxDC&);
+  void OnScale(wxCommandEvent&);
+  void OnMouseMotion(MuniSlewEvent&);
+  void Clear(wxDC&);
+
+public:
+  MuniMagnifierGlass(wxWindow *, const wxSize&, int);
+  void SetImage(const wxImage&);
+  void UnsetImage();
+  int GetScale() const;
+
+};
+
+
+class MuniDisplayMagnifier: public wxFrame
+{
+  MuniConfig *config;
+
+  MuniMagnifierGlass *zoom;
+  wxSlider *slider;
+  void OnMouseMotion(MuniSlewEvent&);
+  void OnClose(wxCloseEvent&);
+  void OnScale(wxCommandEvent&);
+
+public:
+  MuniDisplayMagnifier(wxWindow *, MuniConfig *);
+  void SetImage(const wxImage&);
+  void UnsetImage();
+  int GetScale() const;
 
 };
