@@ -24,17 +24,18 @@
 
 #include "xmunipack.h"
 
-wxDEFINE_EVENT(xEVT_SLEW, MuniSlewEvent);
+wxDEFINE_EVENT(EVT_SLEW, MuniSlewEvent);
+wxDEFINE_EVENT(EVT_CLICK, MuniClickEvent);
 wxDEFINE_EVENT(xEVT_RENDER, MuniRenderEvent);
 wxDEFINE_EVENT(EVT_TUNE, MuniTuneEvent);
 wxDEFINE_EVENT(EVT_FULLTUNE, MuniFullTuneEvent);
 wxDEFINE_EVENT(EVT_ASTROMETRY, MuniAstrometryEvent);
 wxDEFINE_EVENT(EVT_PHOTOMETRY, MuniPhotometryEvent);
-wxDEFINE_EVENT(EVT_HDU, MuniHduEvent);
 wxDEFINE_EVENT(EVT_CONFIG_UPDATED, wxCommandEvent);
-wxDEFINE_EVENT(EVT_DIALOG, MuniDialogEvent);
 wxDEFINE_EVENT(EVT_FITS_OPEN, FitsOpenEvent);
 wxDEFINE_EVENT(EVT_META_OPEN, MetaOpenEvent);
 wxDEFINE_EVENT(EVT_RENDER, MuniRenderEvent);
 wxDEFINE_EVENT(EVT_FILELOAD, wxCommandEvent);
 wxDEFINE_EVENT(EVT_FINISH_DIALOG, wxCommandEvent);
+wxDEFINE_EVENT(EVT_TOOL_FINISH, wxCommandEvent);
+wxDEFINE_EVENT(EVT_DRAW, MuniDrawEvent);
