@@ -31,31 +31,27 @@
 using namespace std;
 
 
-BEGIN_EVENT_TABLE(MuniThumbCanvas, wxWindow)
-  EVT_PAINT(MuniThumbCanvas::OnPaint)
-END_EVENT_TABLE()
-
-
 MuniFileProperties::MuniFileProperties(wxWindow *w, const FitsMeta& fm,
 				       const MuniConfig *config):
 wxDialog(w,wxID_ANY,"Properties of "+fm.GetName()),meta(fm)
 {
   SetIcon(config->munipack_icon);
 
-  wxFont bf(*wxNORMAL_FONT);
-  bf.SetWeight(wxFONTWEIGHT_BOLD);
+  wxSizerFlags label_flags, value_flags;
+  label_flags.Align(wxALIGN_CENTER_VERTICAL|wxALIGN_RIGHT).DoubleBorder(wxRIGHT);
+  value_flags.Align(wxALIGN_CENTER_VERTICAL).Expand();
 
   wxString a;
 
   wxArrayString flabels;
-  flabels.Add("Name:");
-  flabels.Add("Format:");
-  flabels.Add("Type:");
-  flabels.Add("Hdu(s):");
-  flabels.Add("Bytes:");
-  flabels.Add("Access:");
-  flabels.Add("Modified:");
-  flabels.Add("Location:");
+  flabels.Add("Name");
+  flabels.Add("Format");
+  flabels.Add("Type");
+  flabels.Add("Hdu(s)");
+  flabels.Add("Size");
+  flabels.Add("Access");
+  flabels.Add("Modified");
+  flabels.Add("Location");
 
   wxArrayString fvals;
   // name
@@ -109,11 +105,12 @@ wxDialog(w,wxID_ANY,"Properties of "+fm.GetName()),meta(fm)
   // create the table
   for(size_t i = 0; i < flabels.GetCount(); i++) {
 
-    wxStaticText *l = new wxStaticText(gpanel, wxID_ANY, flabels.Item(i));
-    l->SetFont(bf);
-    gright->Add(l,wxSizerFlags().Align(wxALIGN_CENTER_VERTICAL).Border(wxRIGHT));
+    wxString label("<span fgcolor=\"gray\">"+flabels.Item(i)+"</span>");
+    wxStaticText *l = new wxStaticText(gpanel, wxID_ANY, "");
+    l->SetLabelMarkup(label);
+    gright->Add(l,label_flags);
     wxStaticText *x = new wxStaticText(gpanel, wxID_ANY, fvals.Item(i));
-    gright->Add(x,wxSizerFlags().Align(wxALIGN_CENTER_VERTICAL).Expand());
+    gright->Add(x,value_flags);
 
   }
 
@@ -133,16 +130,16 @@ wxDialog(w,wxID_ANY,"Properties of "+fm.GetName()),meta(fm)
     // extname
     a = hdu.GetKey("EXTNAME");
     if( ! a.IsEmpty() ) {
-      hlabels.Add("Extname:");
+      hlabels.Add("Extname");
       hvals.Add(a);
     }
 
     // obj
-    hlabels.Add("Object:");
+    hlabels.Add("Object");
     hvals.Add(hdu.GetKey(config->fits_key_object));
 
     // obs
-    hlabels.Add("Observer:");
+    hlabels.Add("Observer");
     hvals.Add(hdu.GetKey(config->fits_key_observer));
 
     if( hdu.Type() == HDU_IMAGE ) {
@@ -150,31 +147,31 @@ wxDialog(w,wxID_ANY,"Properties of "+fm.GetName()),meta(fm)
       title = "Image";
 
       // axes
-      hlabels.Add("Axes:");
+      hlabels.Add("Axes");
       a.Printf("%d",(int) hdu.Naxis());
       hvals.Add(a);
 
       switch(hdu.SubType()) {
 
       case HDU_IMAGE_LINE:
-	hlabels.Add("Length:");
+	hlabels.Add("Length");
 	a.Printf("%d pix",(int) hdu.Width());
 	hvals.Add(a);
 	break;
 
       case HDU_IMAGE_FRAME:
-	hlabels.Add("Width:");
-	hlabels.Add("Height:");
+	hlabels.Add("Width");
+	hlabels.Add("Height");
 	a.Printf("%d pix",(int) hdu.Width());
 	hvals.Add(a);
 	a.Printf("%d pix",(int) hdu.Height());
 	hvals.Add(a);
 	break;
 
-      case HDU_IMAGE_COLOR:
-	hlabels.Add("Bands:");
-	hlabels.Add("Width:");
-	hlabels.Add("Height:");
+      case HDU_IMAGE_COLOUR:
+	hlabels.Add("Bands");
+	hlabels.Add("Width");
+	hlabels.Add("Height");
 	a.Printf("%d",(int) hdu.Naxes(2));
 	hvals.Add(a);
 	a.Printf("%d pix",(int) hdu.Width());
@@ -184,9 +181,9 @@ wxDialog(w,wxID_ANY,"Properties of "+fm.GetName()),meta(fm)
 	break;
 
       case HDU_IMAGE_CUBE:
-	hlabels.Add("Width:");
-	hlabels.Add("Height:");
-	hlabels.Add("Depth:");
+	hlabels.Add("Width");
+	hlabels.Add("Height");
+	hlabels.Add("Depth");
 	a.Printf("%d pix",(int) hdu.Width());
 	hvals.Add(a);
 	a.Printf("%d pix",(int) hdu.Height());
@@ -200,8 +197,8 @@ wxDialog(w,wxID_ANY,"Properties of "+fm.GetName()),meta(fm)
 
       title = "Table";
 
-      hlabels.Add("Rows:");
-      hlabels.Add("Columns:");
+      hlabels.Add("Rows");
+      hlabels.Add("Columns");
       a.Printf("%d",(int) hdu.Nrows());
       hvals.Add(a);
       a.Printf("%d",(int) hdu.Ncols());
@@ -214,29 +211,29 @@ wxDialog(w,wxID_ANY,"Properties of "+fm.GetName()),meta(fm)
     }
 
     // date & time
-    hlabels.Add("Date:");
-    hlabels.Add("Time:");
+    hlabels.Add("Date");
+    hlabels.Add("Time");
     FitsTime t(hdu.GetKey(config->fits_key_dateobs));
     hvals.Add(t.Date());
     hvals.Add(t.Time());
 
     // filter
-    hlabels.Add("Band:");
+    hlabels.Add("Filter");
     hvals.Add(hdu.GetKey(config->fits_key_filter));
 
     // exp
-    hlabels.Add("Exposure:");
+    hlabels.Add("Exposure");
     a = hdu.Exposure_str(config->fits_key_exptime);
     if( ! a.IsEmpty() )
        a = a + " sec";
     hvals.Add(a);
 
     // type
-    hlabels.Add("Type:");
+    hlabels.Add("Type");
     hvals.Add(hdu.Type_str() + " (" + hdu.SubType_str() + ")");
 
     // range
-    hlabels.Add("Range:");
+    hlabels.Add("Range");
     hvals.Add(hdu.Bitpix_str());
 
 
@@ -254,11 +251,12 @@ wxDialog(w,wxID_ANY,"Properties of "+fm.GetName()),meta(fm)
     // create the table
     for(size_t i = 0; i < hlabels.GetCount(); i++) {
 
-      wxStaticText *l = new wxStaticText(panel, wxID_ANY, hlabels.Item(i));
-      l->SetFont(bf);
-      right->Add(l,wxSizerFlags().Align(wxALIGN_CENTER_VERTICAL).Border(wxRIGHT));
+      wxString label("<span fgcolor=\"gray\">"+hlabels.Item(i)+"</span>");
+      wxStaticText *l = new wxStaticText(panel, wxID_ANY,"");
+      l->SetLabelMarkup(label);
+      right->Add(l,label_flags);
       wxStaticText *x = new wxStaticText(panel, wxID_ANY, hvals.Item(i));
-      right->Add(x,wxSizerFlags().Align(wxALIGN_CENTER_VERTICAL).Expand());
+      right->Add(x,value_flags);
 
     }
 
@@ -289,45 +287,6 @@ wxDialog(w,wxID_ANY,"Properties of "+fm.GetName()),meta(fm)
 }
 
 
-// ------   MuniThumbCanvas
-
-
-MuniThumbCanvas::MuniThumbCanvas(wxWindow *w, const wxBitmap& b):
-  wxWindow(w,wxID_ANY,wxDefaultPosition,wxSize(b.GetWidth(),b.GetHeight())),
-  icon(b)
-{
-  SetBackgroundStyle(wxBG_STYLE_CUSTOM);
-}
-
-void MuniThumbCanvas::OnPaint(wxPaintEvent& WXUNUSED(event))
-{
-  DrawIcon();
-}
-
-void MuniThumbCanvas::SetIcon(const wxBitmap& i)
-{
-  icon = i;
-  DrawIcon();
-}
-
-void MuniThumbCanvas::SetIcon(const wxImage& i)
-{
-  SetIcon(wxBitmap(i));
-}
-
-void MuniThumbCanvas::DrawIcon()
-{
-  if( icon.IsOk() ) {
-    wxSize s = GetSize();
-    int xoff = (s.GetWidth() - icon.GetWidth())/2;
-    int yoff = (s.GetHeight() - icon.GetHeight())/2;
-    wxPaintDC dc(this);
-    dc.DrawBitmap(icon,xoff,yoff,true);
-  }
-}
-
-
-
 // ----  MuniDirProp
 
 
@@ -338,8 +297,10 @@ MuniDirProperties::MuniDirProperties(wxWindow *w, const MuniConfig *config,
   SetIcon(config->munipack_icon);
   EnableCloseButton();
 
-  wxFont bf(*wxNORMAL_FONT);
-  bf.SetWeight(wxFONTWEIGHT_BOLD);
+  wxSizerFlags label_flags, value_flags;
+  label_flags.Align(wxALIGN_CENTER_VERTICAL|wxALIGN_RIGHT).DoubleBorder(wxRIGHT);
+  value_flags.Align(wxALIGN_CENTER_VERTICAL).Expand();
+
 
   wxNotebook *book = new wxNotebook(this,wxID_ANY);
 
@@ -359,13 +320,13 @@ MuniDirProperties::MuniDirProperties(wxWindow *w, const MuniConfig *config,
 
   wxFlexGridSizer *gright = new wxFlexGridSizer(2);
   gright->AddGrowableCol(1);
-  wxStaticText *l1 = new wxStaticText(gpanel, wxID_ANY, "Total Images:");
-  l1->SetFont(bf);
-  gright->Add(l1);
-  gright->Add(new wxStaticText(gpanel, wxID_ANY,a));
-  wxStaticText *l2 = new wxStaticText(gpanel, wxID_ANY, "Total bytes:");
-  l2->SetFont(bf);
-  gright->Add(l2);
+  wxStaticText *l1 = new wxStaticText(gpanel, wxID_ANY, "");
+  l1->SetLabelMarkup("<span fgcolor=\"gray\">Total images</span>");
+  gright->Add(l1,label_flags);
+  gright->Add(new wxStaticText(gpanel, wxID_ANY,a),value_flags);
+  wxStaticText *l2 = new wxStaticText(gpanel, wxID_ANY, "");
+  l2->SetLabelMarkup("<span fgcolor=\"gray\">Total size</span>");
+  gright->Add(l2,label_flags);
 
   wxULongLong size = 0;
   for(vector<FitsMeta>::const_iterator i = flist.begin(); i != flist.end();++i){
@@ -378,11 +339,11 @@ MuniDirProperties::MuniDirProperties(wxWindow *w, const MuniConfig *config,
   }
 
   a = wxFileName::GetHumanReadableSize(size);
-  gright->Add(new wxStaticText(gpanel, wxID_ANY,a));
-  gtop->Add(gright,wxSizerFlags().Center().Border(wxALL));
+  wxStaticText *ss = new wxStaticText(gpanel, wxID_ANY, a);
+  gright->Add(ss,value_flags);
+  gtop->Add(gright,wxSizerFlags(1).Center().Border(wxALL));
 
   gpanel->SetSizer(gtop);
-  gtop->Fit(gpanel);
 
   book->AddPage(gpanel,"General");
 
@@ -390,7 +351,7 @@ MuniDirProperties::MuniDirProperties(wxWindow *w, const MuniConfig *config,
   topsizer->Add(book,wxSizerFlags(1).Expand().Border());
   wxSizer *butt = CreateButtonSizer(wxCLOSE);
   if( butt ) {
-    topsizer->Add(butt,wxSizerFlags().Right().Border(wxBOTTOM));
+    topsizer->Add(butt,wxSizerFlags().Right().Border());
     SetEscapeId(wxID_CLOSE);
   }
   SetSizerAndFit(topsizer);
