@@ -87,7 +87,7 @@ bool FitsHeader::ParseRecord(const wxString& record, wxString& key,
 			     wxString& value, wxString& comment)
 {
   int status = 0;
-  const char *card = static_cast<const char *>(record);
+  const char *card = record.ToAscii();
   char keyname[FLEN_CARD],cval[FLEN_CARD],com[FLEN_CARD];
   int keylen;
 
@@ -1811,7 +1811,7 @@ bool FitsCopyHdu(const wxString& in, const wxString& out, const wxString& hdu)
   int stat = 0;
   int hdutype;
   bool result = false;
-  const char *extname = static_cast<const char *>(hdu);
+  const char *extname = hdu.ToAscii();
 
   fits_open_file(&fin, in.fn_str(), READONLY, &stat);
   fits_open_file(&fout, out.fn_str(), READWRITE, &stat);
