@@ -23,7 +23,6 @@
 
 #ifndef _FITS_H_
 #define _FITS_H_
-#endif
 
 #include <fitsio.h>
 #include <algorithm>
@@ -56,7 +55,7 @@
 #define FITS_KEY_CSPACE "CSPACE"
 
 enum fits_type {
-  FITS_GRAY, FITS_COLOR, FITS_MULTI, FITS_3D,
+  FITS_GRAY, FITS_COLOUR, FITS_MULTI, FITS_3D,
   FITS_SCI, FITS_FLAT, FITS_DARK, FITS_BIAS, FITS_UNKNOWN
 };
 
@@ -65,7 +64,7 @@ enum hdu_type {
 };
 
 enum hdu_flavour {
-  HDU_IMAGE_LINE, HDU_IMAGE_FRAME, HDU_IMAGE_CUBE, HDU_IMAGE_COLOR,
+  HDU_IMAGE_LINE, HDU_IMAGE_FRAME, HDU_IMAGE_CUBE, HDU_IMAGE_COLOUR,
   HDU_IMAGE_UNKNOWN,
   HDU_TABLE_BIN, HDU_TABLE_ASCII, HDU_TABLE_UNKNOWN,
   HDU_DUMMY
@@ -113,10 +112,16 @@ enum tune_operation {
 
 enum units_type {
   UNIT_FIRST,
-  UNIT_COUNT, UNIT_PHOTON, UNIT_MAG, UNIT_INTENSITY, UNIT_STMAG,
+  UNIT_COUNT, UNIT_PHOTON, UNIT_MAG, UNIT_INTENSITY,
   UNIT_LAST
 };
 
+enum phquantity_type {
+  PHQUANTITY_FIRST,
+  PHQUANTITY_COUNT, PHQUANTITY_PHOTON, PHQUANTITY_MAG, PHQUANTITY_INTENSITY,
+  PHQUANTITY_LAST
+};
+
 enum coords_type {
   COO_FIRST,
   COO_PIXEL, COO_EQDEG, COO_EQSIX,
@@ -174,7 +179,7 @@ public:
   virtual long GetWidth() const;
   virtual long GetHeight() const;
   virtual bool IsOk() const;
-  virtual bool IsColor() const;
+  virtual bool IsColour() const;
   virtual bool IsModified() const { return modified; }
 
   virtual inline float Pixel(int) const { return 0; }
@@ -378,10 +383,31 @@ inline float FitsTableColumn::Cell(int x) const
   wxASSERT(data && 0 <= x && x < data->nrows);
 
 	   //if( data->ftable )
-  return data->ftable[x];
+  //  return data->ftable[x];
 	   //  else
 	   //    return 0.0;
 
+
+  if( data->ftable )
+    return data->ftable[x];
+  else if( data->dtable )
+    return data->dtable[x];
+  else if( data->stable )
+    return data->stable[x];
+  else if( data->ltable )
+    return data->ltable[x];
+  else if( data->itable )
+    return data->itable[x];
+  else if( data->btable )
+    return data->btable[x];
+  else if( data->otable )
+    return data->otable[x] ? 1 : 0;
+  else if( data->ctable ) {
+    wxFAIL_MSG("FitsTableColumn::Cell: char to float unimplemented.");
+  }
+
+  return 0.0;
+
   /*
   FitsTableData *data = static_cast<FitsTableData *>(m_refData);
   wxASSERT(data && 0 <= x && x < data->ncols && 0 <= y && y < data->nrows);
@@ -481,7 +507,7 @@ public:
   FitsTable(const FitsHdu&);
   FitsTable Copy() const;
 
-  //  inline float Cell(int,int) const;
+  inline float Cell(int,int) const;
   inline wxString Cell_str(int, int) const;
   //  const float *GetCol_float(int) const;
   //  const char **GetCol_char(int) const;
@@ -543,6 +569,17 @@ private:
 //   //return data->Cell_float(x,y);
 // }
 
+
+inline float FitsTable::Cell(int row, int col) const
+{
+  FitsTableData *data = static_cast<FitsTableData *>(m_refData);
+  wxASSERT(data);
+  const std::vector<FitsTableColumn> columns(data->columns);
+
+  wxASSERT(0 <= col && col < (int) columns.size());
+  return columns[col].Cell(row);
+}
+
 inline wxString FitsTable::Cell_str(int x, int y) const
 {
   FitsTableData *data = static_cast<FitsTableData *>(m_refData);
@@ -609,10 +646,12 @@ public:
   size_t HduCount() const;
   int size() const;
   FitsHdu Hdu(size_t n) const;
+  FitsHdu FindHdu(const wxString&) const;
 
   int Type() const;
   wxString Type_str() const;
   bool HasImage() const;
+  bool HasFind() const;
   bool HasPhotometry() const;
   bool HasPhcal() const;
   wxString GetURL() const;
@@ -763,6 +802,11 @@ public:
 
   bool IsOk() const;
 
+protected:
+
+  wxObjectRefData* CreateRefData() const;
+  wxObjectRefData *CloneRefData(const wxObjectRefData *) const;
+
 private:
 
   float wbin,xmin,xmax;
@@ -970,16 +1014,19 @@ public:
   FitsProjection(const wxString& t, double a,double d, double x, double y,
 		 double cd11, double cd12, double cd21, double cd22);
 
-  void ad2xy(double,double,double&,double&);
-  void xy2ad(double,double,double&,double&);
-  void gnomon(double,double,double&,double&);
-  void ignomon(double,double,double&,double&);
+  void ad2xy(double,double,double&,double&) const;
+  void xy2ad(double,double,double&,double&) const;
+  double GetScale() const;
+  bool IsOk() const;
 
 private:
 
   wxString type;
   double acen, dcen, xcen, ycen, scale, angle, reflex;
 
+  void gnomon(double,double,double&,double&) const;
+  void ignomon(double,double,double&,double&) const;
+
 };
 
 
@@ -995,12 +1042,12 @@ public:
   void SetType(const wxString&);
   coords_type GetType() const;
 
-  void GetEq(int,int,double&,double&);
-  void RaSix(double,int&,int&,double&);
-  void DecSix(double,char&,int&,int&,double&);
+  void GetEq(int,int,double&,double&) const;
+  void RaSix(double,int&,int&,double&) const;
+  void DecSix(double,char&,int&,int&,double&) const;
 
-  void GetPix(int,int,wxString&,wxString&);
-  void GetCoo(int,int,wxString&,wxString&);
+  void GetPix(int,int,wxString&,wxString&) const;
+  void GetCoo(int,int,wxString&,wxString&) const;
 
   bool HasWCS() const;
 
@@ -1012,6 +1059,7 @@ private:
   FitsProjection proj;
   coords_type type;
   bool haswcs;
+  int digits;
 
 };
 
@@ -1072,7 +1120,6 @@ class PhotoConv
 
   double GetIntensity(double) const;
   double GetMag(double) const;
-  double GetSTMag(double) const;
 
 };
 
@@ -1087,14 +1134,18 @@ public:
   void SetType(int);
   void SetType(const wxString&);
   units_type GetType() const;
+  wxString GetName() const;
+  wxString GetUnit() const;
 
   wxString Get_str(int,int) const;
   wxString Get_str(int,int,int) const;
 
   static wxString Label_str(int);
   static wxArrayString Label_str();
+  static wxString Units_str(int);
+  static wxArrayString Units_str();
 
-  bool HasCal() const { return hascal; }
+  bool HasPhcal() const { return hascal; }
 
 private:
 
@@ -1158,7 +1209,7 @@ public:
   size_t GetCount() const;
   FitsArray Item(size_t) const;
   bool IsOk() const;
-  bool IsColor() const;
+  bool IsColour() const;
   int GetWidth() const;
   int GetHeight() const;
   long Npixels() const;
@@ -1352,27 +1403,13 @@ private:
 };
 
 
-class FitsZoom
-{
-  int shrink,zoom;
-  static const int nratios;
-  static const int ratios[];
-
-public:
-  FitsZoom();
-  FitsZoom(int,int=ZOOM_SHRINK);
-  FitsZoom(const FitsZoom&);
-  FitsZoom& operator = (const FitsZoom&);
-
-  int GetKind() const;
-  int GetZoom() const;
-  int GetShrink() const;
-  FitsZoom GetIn() const;
-  FitsZoom GetOut() const;
-};
-
-
 // auxiliary  functions
 
 bool FitsCopyFile(const wxString&,const wxString&);
+bool FitsCopyHdu(const wxString&,const wxString&,const wxString&);
 //wxArrayString FitsColumns(const wxString&);
+
+wxString HumanFormat(double);
+
+
+#endif
