@@ -3,7 +3,7 @@
   xmunipack - fits meta-info
 
 
-  Copyright © 2009-2011 F.Hroch (hroch@physics.muni.cz)
+  Copyright © 2009-2011, 2019 F.Hroch (hroch@physics.muni.cz)
 
   This file is part of Munipack.
 
@@ -28,6 +28,7 @@
 #include <vector>
 #include <wx/wx.h>
 #include <wx/uri.h>
+#include <wx/filesys.h>
 
 #ifdef __WXDEBUG__
 #include <wx/debug.h>
@@ -206,8 +207,8 @@ FitsMeta::FitsMeta(const wxString& u, const wxString& t,
 {
   if( type_str == "Gray image" )
     type = FITS_GRAY;
-  else if( type_str == "Color image" )
-    type = FITS_COLOR;
+  else if( type_str == "Colour image" )
+    type = FITS_COLOUR;
   else if( type_str == "Multi layer" )
     type = FITS_MULTI;
 }
@@ -289,7 +290,7 @@ wxString FitsMeta::GetDateobs(const wxString& key) const
 
 wxString FitsMeta::GetFilter(const wxString& key) const
 {
-  return type == FITS_COLOR ? "RGB" : GetKeys(key);
+  return type == FITS_COLOUR ? "RGB" : GetKeys(key);
 }
 
 wxString FitsMeta::GetExposure(const wxString& key) const
