@@ -3,7 +3,7 @@
   xmunipack - icon
 
 
-  Copyright © 2009-2012, 2018 F.Hroch (hroch@physics.muni.cz)
+  Copyright © 2009-2012, 2018-9 F.Hroch (hroch@physics.muni.cz)
 
   This file is part of Munipack.
 
@@ -71,7 +71,7 @@ MuniIcon::MuniIcon(const FitsFile& f, const wxString& cs, const wxString& cd,
   // cover icon
   switch(fits.Type()) {
   case FITS_GRAY:
-  case FITS_COLOR:
+  case FITS_COLOUR:
     wxASSERT(fits.HasImage() &&
 	     fits.Hdu(0).Type() == HDU_IMAGE && fits.Hdu(0).IsOk());
     icon = list[0];
@@ -118,7 +118,7 @@ MuniIcon::MuniIcon(const FitsFile& f, const wxString& cs, const wxString& cd,
   // cover icon
   switch(fits.Type()) {
   case FITS_GRAY:
-  case FITS_COLOR:
+  case FITS_COLOUR:
     wxASSERT(fits.HasImage() &&
 	     fits.Hdu(0).Type() == HDU_IMAGE && fits.Hdu(0).IsOk());
     icon = list[0];
@@ -150,7 +150,7 @@ wxImage MuniIcon::ImageIcon(const FitsArray& a) const
 {
   wxASSERT(a.IsOk());
 
-  if( a.Flavour() == HDU_IMAGE_COLOR ){
+  if( a.Flavour() == HDU_IMAGE_COLOUR ){
     FitsTone tone(a.Plane(1));
     FitsColor color(cdatafile,a);
     return ColorIcon(a,tone,color);
