@@ -3,7 +3,7 @@
   xmunipack - preview icon list
 
 
-  Copyright © 2009 - 2013 F.Hroch (hroch@physics.muni.cz)
+  Copyright © 2009 - 2013, 2019 F.Hroch (hroch@physics.muni.cz)
 
   This file is part of Munipack.
 
@@ -68,28 +68,28 @@ static bool CmpName(const FitsMeta& meta1, const FitsMeta& meta2)
 {
   wxString name1 = meta1.GetName();
   wxString name2 = meta2.GetName();
-  return wxStrcmp(name1.c_str(),name2.c_str()) < 0;
+  return wxStrcmp(name1,name2) < 0;
 }
 
 static bool CmpObject(const FitsMeta& meta1, const FitsMeta& meta2)
 {
   wxString key1 = meta1.GetKeys(sort_object);
   wxString key2 = meta2.GetKeys(sort_object);
-  return wxStrcmp(key1.c_str(),key2.c_str()) < 0;
+  return wxStrcmp(key1,key2) < 0;
 }
 
 static bool CmpFilter(const FitsMeta& meta1, const FitsMeta& meta2)
 {
   wxString key1 = meta1.GetFilter(sort_filter);
   wxString key2 = meta2.GetFilter(sort_filter);
-  return wxStrcmp(key1.c_str(),key2.c_str()) < 0;
+  return wxStrcmp(key1,key2) < 0;
 }
 
 static bool CmpKey(const FitsMeta& meta1, const FitsMeta& meta2)
 {
   wxString key1 = meta1.GetKeys(sort_key);
   wxString key2 = meta2.GetKeys(sort_key);
-  return wxStrcmp(key1.c_str(),key2.c_str()) < 0;
+  return wxStrcmp(key1,key2) < 0;
 }
 
 static bool CmpExposure(const FitsMeta& meta1, const FitsMeta& meta2)
