@@ -23,35 +23,25 @@
 
 #ifndef _XMUNIPACK_CONFIG_H_
 #define _XMUNIPACK_CONFIG_H_
-#endif
 
-#ifndef _XMUNIPACK_ENUM_H_
 #include "enum.h"
-#endif
-
-#ifndef _FITS_H_
 #include "fits.h"
-#endif
-
-#ifndef _XMUNIPACK_ICON_H_
 #include "icon.h"
-#endif
-
 #include <wx/config.h>
 #include <wx/animate.h>
 #include <wx/artprov.h>
 
 
-
 class MuniArtIcons
 {
-public:
-  MuniArtIcons(const wxArtClient& =wxART_OTHER, const wxSize& =wxDefaultSize);
-  wxBitmap Icon(const wxArtID&) const;
-
-private:
   const wxArtClient client;
   const wxSize size;
+
+ public:
+  MuniArtIcons(const wxArtClient& =wxART_OTHER, const wxSize& =wxDefaultSize);
+  wxBitmap Icon(const wxArtID&) const;
+  wxBitmap IncludedIcon(const wxArtID&) const;
+
 };
 
 
@@ -61,22 +51,25 @@ public:
   MuniConfig();
   virtual ~MuniConfig();
 
-  wxSize browser_size, view_size, help_size, console_size, colorization_size,
-    header_size;
+  wxSize browser_size, view_size, help_size, /*console_size,*/colorization_size,
+    header_size, aphot_size;
   int icon_size,icon_small,icon_zoom;
-  int scroll_rate,detail_zoom,detail_scale;
+  int scroll_rate, extlist_show, caption_show,
+    detail_show, detail_zoom,detail_scale;
   int display_pal,display_coo,display_val;
-  bool display_palinv, display_palauto;
+  bool display_palinv;
   int browser_labeltype,browser_sorttype, browser_iconlist;
   bool astrometry_fullmatch;
   int astrometry_minmatch, astrometry_maxmatch;
   double astrometry_sig, astrometry_fsig;
-  double photo_fwhm, photo_thresh, photo_satur, photo_readns, photo_phpadu;
+  double find_fwhm, find_thresh;
+  int aphot_naper, aphot_rmin, aphot_rmax, aphot_zoom, aphot_saper;
+  bool aphot_spiral, aphot_snap;
   wxString astrometry_proj, astrometry_units;
   bool browser_reverse;
   int browser_sash;
   int icon_menu_width,icon_menu_height;
-  bool browser_collector, browser_tbar, view_tbar, console_wrap;
+  bool browser_collector, browser_tbar, view_tbar/*, console_wrap*/;
   bool display_grid, display_sources;
   wxString dirmask, rawmask, fits_key_object, fits_key_dateobs,fits_key_exptime,
     fits_key_filter, fits_key_observer, fits_key_gain, fits_key_area,
@@ -86,8 +79,15 @@ public:
   wxImage default_icon, table_icon, head_icon;
   wxAnimation throbber;
 
+  // Magnifier
+  wxSize magnifier_size;
+  int magnifier_scale;
+  bool magnifier_show;
+
   static wxString FindIconPath(const wxString& name);
   static wxIcon LoadIcon(const wxString&);
   static wxImage LoadImage(const wxString&);
 
 };
+
+#endif
