@@ -141,8 +141,10 @@ void MuniPhotometryLayer::DrawObjects(const vector<double>& xcoo, const vector<d
 
 
 MuniPhotometry::MuniPhotometry(wxWindow *w, MuniConfig *c, const wxString& f):
-  MuniBaseDialog(w,"Photometry",c,f),fwhm(c->photo_fwhm),thresh(c->photo_thresh),
+  MuniBaseDialog(w,"Photometry",c,f),
+  /*fwhm(c->photo_fwhm),thresh(c->photo_thresh),
   saturation(c->photo_satur),readnoise(c->photo_readns),phpadu(c->photo_phpadu),
+  */
   erase(false),apply(false),showtooltip(true)
 {
   SetIcon(config->munipack_icon);
@@ -230,11 +232,11 @@ MuniPhotometry::~MuniPhotometry()
 {
   wxLogDebug("MuniPhotometry::~MuniPhotometry");
 
+  /*
   config->photo_fwhm = fwhm;
   config->photo_thresh = thresh;
   config->photo_satur = saturation;
-  config->photo_readns = readnoise;
-  config->photo_phpadu = phpadu;
+  */
 }
 
 wxString MuniPhotometry::GetBackup() const
