@@ -50,8 +50,8 @@ public:
     }
     return hmax;
   }
-  void Plot(wxDC& dc, mpWindow& win) {
-
+  void Plot(wxDC& dc, mpWindow& win)
+  {
     wxPen hpen(*wxLIGHT_GREY_PEN);
 
     // width of bins
@@ -75,49 +75,47 @@ public:
     dc.SetPen(*wxWHITE_PEN);
     dc.DrawRectangle(1,1,width-2,height-2);
   }
-};
 
+};
 
 
 // -- MuniPlotHisto  --------------------------------------------
 
-MuniPlotHisto::MuniPlotHisto(wxWindow *w, bool t):
-  mpWindow(w,wxID_ANY),
-  itt_plot(false),axes(t),hmax(1),xmin(0.0),xmax(0.0),
-  bestsize(axes ? wxSize(300,185) : wxSize(162,100))
+MuniPlotHisto::MuniPlotHisto(wxWindow *w):
+  mpWindow(w,wxID_ANY), hmax(1),xmin(0.0),xmax(0.0)
 {
 }
 
 wxSize MuniPlotHisto::DoGetBestSize() const
 {
-  return bestsize;
+  return wxSize(162,100);
 }
 
-void MuniPlotHisto::SetItt(const FitsItt& i)
+void MuniPlotHisto::SetArray(const FitsArray& a)
 {
-  itt_plot = true;
-  itt = i;
+  wxASSERT(a.IsOk());
+  hlist.clear();
+  hlist.push_back(FitsHisto(a));
+  Plot();
 }
 
-void MuniPlotHisto::SetHisto(const FitsHisto& hl)
+void MuniPlotHisto::SetArray(const std::vector<FitsArray>& arrays)
 {
   hlist.clear();
-  hlist.push_back(hl);
-  SetHisto(hlist);
+  for(vector<FitsArray>::const_iterator a = arrays.begin(); a!=arrays.end();++a)
+    if( a->IsOk() ) {
+      hlist.push_back(FitsHisto(*a));
+    }
+
+  Plot();
 }
 
-void MuniPlotHisto::SetHisto(const std::vector<FitsHisto>& h)
+void MuniPlotHisto::Plot()
 {
-  vector<FitsHisto> hs = h;
-  hlist.clear();
-  for(vector<FitsHisto>::const_iterator k = hs.begin(); k != hs.end();++k)
-    if( k->IsOk() )
-      hlist.push_back(*k);
-
   // search for maximum in histogram
-  hmax = 0;
-  for(vector<FitsHisto>::const_iterator k = hlist.begin(); k!=hlist.end();++k){
-    FitsHisto hist = *k;
+  hmax = 1;
+  for(vector<FitsHisto>::const_iterator h = hlist.begin(); h!=hlist.end();++h){
+    FitsHisto hist(*h);
     for(int i = 0; i < hist.NBins(); i++ ) {
       if( hist.Hist(i) > hmax )
         hmax = hist.Hist(i);
@@ -125,58 +123,31 @@ void MuniPlotHisto::SetHisto(const std::vector<FitsHisto>& h)
   }
 
   // set range of values
-  /*
-  FitsHisto hist = hlist[hlist.size() == 1 ? 0 : 1];
-  wxASSERT(hist.IsOk());
-  xmin = hist.CentsMin();
-  xmax = hist.CentsMax();
-  */
-
   xmin = numeric_limits<double>::max();
   xmax = -xmin;
-  for(vector<FitsHisto>::const_iterator k = hlist.begin(); k!=hlist.end();++k){
-    FitsHisto hist = *k;
-    if( xmin > hist.Cents(0) )
-      xmin = hist.Cents(0);
-    if( xmax < hist.Cents(hist.NBins()-1) )
-      xmax = hist.Cents(hist.NBins()-1);
+  for(vector<FitsHisto>::const_iterator h = hlist.begin(); h!=hlist.end();++h){
+    FitsHisto hist(*h);
+    if( xmin > hist.CentsMin() )
+      xmin = hist.CentsMin();
+    if( xmax < hist.CentsMax() )
+      xmax = hist.CentsMax();
   }
-
-  /*
-  xmin = hist.Cents(0);
-  for(int i = 0; i < hist.NBins()-1; i++)
-    if( hist.Hist(i) > 0 ) {
-      xmin = hist.Cents(i);
-      break;
-    }
-
-  xmax = hist.Cents(hist.NBins()-1);
-  for(int i = hist.NBins()-1; i > 0 ; i--)
-    if( hist.Hist(i) > 0 ) {
-      xmax = hist.Cents(i);
-      break;
-    }
-  */
-
-  /*
-  if( hlist.size() == 1 ) {
-    FitsHisto hist = hlist[0];
-    xmin = hist.Cents(0);
-    xmax = hist.Cents(hist.NBins()-1);
-  }
-  else if ( hlist.size() > 1 ) {
-    FitsHisto hist = hlist[1];
-    xmin = hist.Cents(0);
-    xmax = hist.Cents(hist.NBins()-1);
-  }
-  */
-
   //wxLogDebug("/// %f %f %d",xmin,xmax,hmax);
 
   DelAllLayers(true,false);
 
-  if ( ! h.empty() ) {
-    mpHistogram *l = new mpHistogram(h[0]);
+  if ( ! hlist.empty() ) {
+    mpHistogram *l = new mpHistogram(hlist[0]);
+    /*
+    vector<double> x,y;
+    FitsHisto h = hlist[0];
+    for(size_t i = 0; i < h.NBins(); i++) {
+      x.push_back(h.Cents(i));
+      y.push_back(h.Hist(i));
+    }
+    mpFXYVector *l = new mpFXYVector("");
+    l->SetData(x,y);
+    */
     wxPen hpen(*wxLIGHT_GREY_PEN);
     hpen.SetWidth(10);
     l->SetPen(hpen);
