@@ -41,6 +41,8 @@ MuniTune::MuniTune(wxWindow *w, wxWindowID id, const wxPoint& pos,
   tone(t),itt(i),pal(p),shrinking(true),colouring(false),
   toneabs(false),render(true), ittline(true),nitevision(false), etune(0)
 {
+  //  wxLogDebug("MuniTune::MuniTune gray");
+
   // tune display
   display = new FitsGrayDisplay(array);
 
@@ -66,7 +68,7 @@ MuniTune::MuniTune(wxWindow *w, wxWindowID id, const wxPoint& pos,
   topsizer->Add(book,wxSizerFlags().Border().Expand());
   topsizer->Add(new wxButton(this, ID_RESET, "Reset All"),
 		wxSizerFlags().Center().Border());
-  SetSizer(topsizer);
+  SetSizerAndFit(topsizer);
 
   // events
   Bind(wxEVT_CLOSE_WINDOW,&MuniTune::OnClose,this);
@@ -74,9 +76,6 @@ MuniTune::MuniTune(wxWindow *w, wxWindowID id, const wxPoint& pos,
   Bind(EVT_TUNE,&MuniTune::OnTuneFine,this);
   Bind(wxEVT_IDLE,&MuniTune::OnIdle,this);
   Bind(wxEVT_SCROLL_THUMBTRACK,&MuniTune::OnScroll,this);
-
-  Layout();
-  GetSizer()->SetSizeHints(this);
 }
 
 MuniTune::MuniTune(wxWindow *w, wxWindowID id, const wxPoint& pos,
@@ -115,16 +114,13 @@ MuniTune::MuniTune(wxWindow *w, wxWindowID id, const wxPoint& pos,
   topsizer->Add(book,wxSizerFlags().Border().Expand());
   topsizer->Add(new wxButton(this, ID_RESET, "Reset All"),
 		wxSizerFlags().Center().Border());
-  SetSizer(topsizer);
+  SetSizerAndFit(topsizer);
 
   Bind(wxEVT_CLOSE_WINDOW,&MuniTune::OnClose,this);
   Bind(wxEVT_COMMAND_BUTTON_CLICKED,&MuniTune::OnReset,this,ID_RESET);
   Bind(EVT_TUNE,&MuniTune::OnTuneFine,this);
   Bind(wxEVT_IDLE,&MuniTune::OnIdle,this);
   Bind(wxEVT_SCROLL_THUMBTRACK,&MuniTune::OnScroll,this);
-
-  Layout();
-  GetSizer()->SetSizeHints(this);
 }
 
 MuniTune::~MuniTune()
@@ -139,18 +135,18 @@ void MuniTune::InitMini(const FitsArray& a,int icon_size,int *width,int *height)
   wxASSERT(display && shrinking);
 
   if( a.Width() > a.Height() ) {
-    int s = a.Width() / (2*icon_size);
+    int s = wxMax(a.Width() / (2*icon_size),1);
     *width = a.Width() / s;
     *height = a.Height() / s;
     display->SetShrink(s);
   }
   else {
-    int s = a.Height() / (2*icon_size);
+    int s = wxMax(a.Height() / (2*icon_size),1);
     *width = a.Height() / s;
     *height = a.Height() / s;
     display->SetShrink(s);
   }
-  //  wxLogDebug("preview: %d %d %d",*width,*height,icon_size);
+  //wxLogDebug("preview: %d %d %d",*width,*height,icon_size);
 }
 
 
@@ -244,18 +240,18 @@ MuniTuneLogjuster *MuniTune::CreateToneSense(wxWindow *tpanel)
   //  if( tone.GetKind() == TONE_KIND_ABS ) {
   if( toneabs ) {
     r = tone.GetSense();
-    rmin = 1e-3*r;
-    rmax = 1e3*r;
-    inc = 1e-3*r;
+    rmin = 1e-2*r;
+    rmax = 1e2*r;
+    inc = 1e-2*r;
     digits = 3;
     id = ID_TONE_SENSE;
 
   }
   else { // tone.GetKind() == TONE_KIND_REL ) {
     r = tone.GetRsense();
-    rmin = 1e-3;
-    rmax = 1e3;
-    inc = 1e-3;
+    rmin = 1e-2;
+    rmax = 1e2;
+    inc = 1e-2;
     digits = 3;
     id = ID_TONE_RSENSE;
   }
@@ -424,23 +420,23 @@ wxNotebookPage *MuniTune::CreateLutTab(wxNotebook *book)
 {
   wxNotebookPage *ppanel = new wxPanel(book);
 
-  wxBoxSizer *lsizer = new wxBoxSizer(wxVERTICAL);
-
-  wxBoxSizer *cchoice = new wxBoxSizer(wxHORIZONTAL);
   lutch = new wxChoice(ppanel,ID_CHOICE_PAL,wxDefaultPosition,
 		       wxDefaultSize,FitsPalette::Type_str());
   lutch->SetStringSelection(pal.GetPalette_str());
-  cchoice->Add(lutch,wxSizerFlags().Align(wxALIGN_CENTER_VERTICAL|wxALIGN_CENTER).Border(wxRIGHT));
 
   invcheck = new wxCheckBox(ppanel,ID_CHECK_INVERSE,"Inverse");
   invcheck->SetValue(pal.GetInverse());
-  cchoice->Add(invcheck,wxSizerFlags(1).Align(wxALIGN_CENTER_VERTICAL|
-					      wxALIGN_CENTER).Border(wxLEFT));
-  lsizer->Add(cchoice,wxSizerFlags().Border().Center());
 
   lutus = new MuniLUTus(ppanel);
   lutus->SetPalette(pal);
-  lsizer->Add(lutus,wxSizerFlags().Border().Center());
+
+  wxBoxSizer *cchoice = new wxBoxSizer(wxHORIZONTAL);
+  cchoice->Add(lutch,wxSizerFlags().Align(wxALIGN_CENTER_VERTICAL|wxALIGN_CENTER).Border(wxRIGHT));
+  cchoice->Add(invcheck,wxSizerFlags(1).Align(wxALIGN_CENTER_VERTICAL|
+					      wxALIGN_CENTER).Border(wxLEFT));
+  wxBoxSizer *lsizer = new wxBoxSizer(wxVERTICAL);
+  lsizer->Add(cchoice,wxSizerFlags().Border().Center());
+  lsizer->Add(lutus,wxSizerFlags().Border().Expand());
 
   ppanel->SetSizer(lsizer);
 
