@@ -25,16 +25,9 @@
 
 #ifndef _XMUNIPACK_TUNE_H
 #define _XMUNIPACK_TUNE_H
-#endif
 
-#ifndef _FITS_H_
 #include "fits.h"
-#endif
-
-#ifndef _XMUNIPACK_EVENT_H_
 #include "event.h"
-#endif
-
 #include <wx/wx.h>
 #include <wx/notebook.h>
 #include <wx/spinctrl.h>
@@ -44,7 +37,6 @@ class MuniLUTus: public wxPanel
 {
 public:
   MuniLUTus(wxWindow *);
-  wxSize DoGetBestSize() const;
 
   void SetPalette(const FitsPalette&);
   void SetPalette(const wxString&);
@@ -202,3 +194,5 @@ private:
   wxNotebookPage *CreateNiteTab(wxNotebook *);
 
 };
+
+#endif
