@@ -129,6 +129,17 @@ units_type FitsValue::GetType() const
   return type;
 }
 
+wxString FitsValue::GetName() const
+{
+  return Label_str(type);
+}
+
+
+wxString FitsValue::GetUnit() const
+{
+  return Units_str(type);
+}
+
 wxString FitsValue::ToString(double d, int k) const
 {
   wxString a;
@@ -137,7 +148,7 @@ wxString FitsValue::ToString(double d, int k) const
     if( array.Bitpix() > 0 )
       a.Printf("%d",int(d+0.5));
     else
-      a.Printf("%.5g",d);
+      a = HumanFormat(d);
   }
 
   if( hascal ) {
@@ -148,11 +159,8 @@ wxString FitsValue::ToString(double d, int k) const
 
     else if( type == UNIT_INTENSITY )
 
-      a.Printf("%.5g",phconv[k].GetIntensity(d));
+      a = HumanFormat(d);
 
-    else if( type == UNIT_STMAG )
-
-      a.Printf("%.5g",phconv[k].GetSTMag(d));
   }
 
   return a;
@@ -182,12 +190,11 @@ wxString FitsValue::Get_str(int i, int j, int k) const
 wxString FitsValue::Label_str(int n)
 {
   switch(n){
-  case UNIT_COUNT:     return  "count";
-  case UNIT_PHOTON:    return  "photon";
-  case UNIT_MAG:       return L"mag/arcsec²";
-  case UNIT_INTENSITY: return L"eV/s/m²/arcsec²";
-  case UNIT_STMAG:     return L"stmag/arcsec²";
-  default:             return  "";
+  case PHQUANTITY_COUNT:     return "Count";
+  case PHQUANTITY_PHOTON:    return "Photon";
+  case PHQUANTITY_MAG:       return "Magnitude";
+  case PHQUANTITY_INTENSITY: return "Intensity";
+  default:                   return  "???";
   }
 }
 
@@ -195,12 +202,32 @@ wxArrayString FitsValue::Label_str()
 {
   wxArrayString a;
 
-  for(int i = UNIT_FIRST+1; i < UNIT_LAST; i++)
+  for(int i = PHQUANTITY_FIRST+1; i < PHQUANTITY_LAST; i++)
     a.Add(Label_str(i));
 
   return a;
 }
 
+wxString FitsValue::Units_str(int n)
+{
+  switch(n){
+  case UNIT_COUNT:     return  "";
+  case UNIT_PHOTON:    return  "";
+  case UNIT_MAG:       return L"mag/arcsec²";
+  case UNIT_INTENSITY: return L"eV/s/m²/arcsec²";
+  default:             return  "";
+  }
+}
+
+wxArrayString FitsValue::Units_str()
+{
+  wxArrayString a;
+
+  for(int i = UNIT_FIRST+1; i < UNIT_LAST; i++)
+    a.Add(Units_str(i));
+
+  return a;
+}
 
 
 // ----- Photometric Systems
@@ -209,7 +236,6 @@ const double PhotoConv::cspeed = 299792458.0;
 const double PhotoConv::hplanck = 6.62606957e-34;
 const double PhotoConv::evolt = 1.6021766208e-19;  // = 1eV
 const double PhotoConv::sqrtpi2 = 1.2533141373155001; // = sqrt(pi/2)
-const double PhotoConv::STspflux = 3.6335e-10; // [W/m2/nm]
 
 PhotoConv::PhotoConv(const PhotoFilter& phfilter, double a, double e, double s):
   area(a), exptime(e), scale(s)
@@ -242,12 +268,6 @@ double PhotoConv::GetMag(double photon) const
   return mag(intensity(photon), sqrtpi2 * flam * (1e9*lwidth));
 }
 
-double PhotoConv::GetSTMag(double photon) const
-{
-  return mag(intensity(photon), sqrtpi2 * (1e9 * lwidth) * STspflux);
-}
-
-
 
 FitsPhotosystems::FitsPhotosystems(const wxString& name)
 {
@@ -273,7 +293,6 @@ FitsPhotosystems::FitsPhotosystems(const wxString& name)
     if( status ) goto crash;
 
     fits_read_keyword(f,"EXTNAME",extname,comment,&status);
-    wxLogDebug(extname);
 
     // removing aphostrophes
     wxString e(extname);
@@ -311,8 +330,6 @@ FitsPhotosystems::FitsPhotosystems(const wxString& name)
 		    &dummy,&status);
       fits_read_col(f,TDOUBLE,col[3], frow, felem, nrows, &nullval,flam,
 		    &dummy,&status);
-
-
       if( status ) goto crash;
 
       vector<PhotoFilter> phfs;
