@@ -33,10 +33,14 @@
 #include <wx/wupdlock.h>
 #include <wx/combo.h>
 #include <wx/progdlg.h>
-#include <wx/fswatcher.h>
 #include <wx/filename.h>
 #include <wx/filefn.h>
 
+#if wxUSE_FSWATCHER
+#include <wx/fswatcher.h>
+#endif
+
+
 #define MENU_IMAGE "Image"
 #define MENU_HEAD "Head"
 #define MENU_TABLE "Table"
@@ -49,8 +53,11 @@ using namespace std;
 
 MuniView::MuniView(wxWindow *w, MuniConfig *c):
   wxFrame(w, wxID_ANY,"untitled", wxDefaultPosition, c->view_size),
-  config(c), fswatch(0), loadfile(false), hdusel(0),
-  loader(0), zoomctrl(0), /* coloring(0),*/ aphot(0)
+  config(c), loadfile(false), hdusel(0), loader(0), zoomctrl(0), /* coloring(0),*/
+  aphot(0)
+#if wxUSE_FSWATCHER
+  ,fswatch(0)
+#endif
 {
   SetIcon(config->munipack_icon);
 
@@ -228,13 +235,17 @@ MuniView::MuniView(wxWindow *w, MuniConfig *c):
 
 MuniView::~MuniView()
 {
+#if wxUSE_FSWATCHER
   delete fswatch;
+#endif
 }
 
 void MuniView::OnIdle(wxIdleEvent& event)
 {
   //  wxLogDebug("MuniView::OnIdle");
 
+
+#if wxUSE_FSWATCHER
   // File monitor -- re-load
   if( loadfile ) {
     wxString filename(fits.GetFullPath());
@@ -249,6 +260,7 @@ void MuniView::OnIdle(wxIdleEvent& event)
     wxLogDebug("Re-loading "+filename);
     LoadFile(filename);
   }
+#endif
 }
 
 void MuniView::OnSize(wxSizeEvent& event)
@@ -329,19 +341,27 @@ void MuniView::OnClose(wxCloseEvent& event)
   Destroy();
 }
 
+
+
 void MuniView::CreateFSWatch()
 {
   //  wxLogDebug("MuniView::CreateFSWatch");
 
+#if wxUSE_FSWATCHER
+
   if( fswatch ) return;
 
   fswatch = new wxFileSystemWatcher();
   fswatch->SetOwner(this);
   Bind(wxEVT_FSWATCHER, &MuniView::OnFileSystemEvent, this);
+#endif
 }
 
+
 void MuniView::MonitorFile(const wxString& filename)
 {
+#if wxUSE_FSWATCHER
+
   const int flags = wxPATH_GET_VOLUME | wxPATH_GET_SEPARATOR;
 
   if( !fswatch ) return;
@@ -356,10 +376,13 @@ void MuniView::MonitorFile(const wxString& filename)
   fswatch->RemoveAll();
   fswatch->Add(path);
   wxLogDebug("Monitoring: "+filename+" in "+path);
+#endif
 }
 
+#if wxUSE_FSWATCHER
 void MuniView::OnFileSystemEvent(wxFileSystemWatcherEvent& event)
 {
+
   wxString fitsname(fits.GetFullPath());
   wxString eventname(event.GetPath().GetFullPath());
 
@@ -383,6 +406,7 @@ void MuniView::OnFileSystemEvent(wxFileSystemWatcherEvent& event)
     fswatch->RemoveAll();
   }
 }
+#endif
 
 double MuniView::MonitorDelay(const wxString& filename) const
 {
@@ -398,6 +422,7 @@ double MuniView::MonitorDelay(const wxString& filename) const
 }
 
 
+
 bool MuniView::IsModified() const
 {
   return ! backup.IsEmpty();
@@ -452,8 +477,10 @@ void MuniView::LoadFile(const wxString& filename)
   meta = FitsMeta();
   LoadStart(filename);
 
+#if wxUSE_FSWATCHER
   if( fswatch )
     fswatch->RemoveAll();
+#endif
 }
 
 void MuniView::LoadFileBackup(const wxString& file, const wxString& b)
